class TableInterface:
    def get_number_seasons() -> str:
        pass

    def get_overview() -> str:
        pass

    def get_date() -> str:
        pass

    def get_time() -> str:
        pass

    def get_imdb() -> str:
        pass

    def get_classification() -> str:
        pass

    def get_trailers() -> str:
        pass
